Module allocator

Module allocator 

Allocators moddule.

Structs

ContiguousMemoryLayoutPolicy
Allocators where every allocations is with contiguous memory.
PitchedMemoryLayoutPolicy
Allocators where some allocations can leverage a pitched layout.

Functions

offset_handles
Take a list of sub-slices of a buffer and create a list of offset handles. Sizes must be in bytes and handles will be aligned to the memory alignment.