pub enum TimingMethod {
System,
Device,
}Expand description
How a benchmark’s execution times are measured.
Variants
System
Time measurements come from full timing of execution + sync calls.
Device
Time measurements come from hardware reported timestamps coming from a sync call.