pub struct KernelId {
pub cube_dim: Dim3,
pub address_type: AddressType,
pub mode: ExecutionMode,
/* private fields */
}Expand description
Kernel unique identifier.
Fields
cube_dim: Dim3The [CubeDim] for this kernel
address_type: AddressTypeThe address type for this kernel
mode: ExecutionModeThe execution mode for this kernel
Implementations
Sourceimpl KernelId
impl KernelId
Sourcepub fn stable_format(&self) -> String
pub fn stable_format(&self) -> String
Render the key in a standard format that can be used between runs.
Can be used as a persistent kernel cache key.
Sourcepub fn stable_hash(&self) -> u128
pub fn stable_hash(&self) -> u128
Hash the key in a stable way that can be used between runs.
Can be used as a persistent kernel cache key.
Sourcepub fn info<I: 'static + PartialEq + Eq + Hash + Debug + Send + Sync>(
self,
info: I,
) -> Self
pub fn info<I: 'static + PartialEq + Eq + Hash + Debug + Send + Sync>( self, info: I, ) -> Self
Add information to the kernel id.
The information is used to differentiate kernels of the same kind but with different configurations, which affect the generated code.
Sourcepub fn mode(self, mode: ExecutionMode) -> Self
pub fn mode(self, mode: ExecutionMode) -> Self
Set the execution mode.
Sourcepub fn address_type(self, addr_ty: AddressType) -> Self
pub fn address_type(self, addr_ty: AddressType) -> Self
Set the AddressType.