pub struct KernelArg {
pub id: Id,
pub visibility: Visibility,
pub ty: Type,
pub size: Option<usize>,
pub has_extended_meta: bool,
}Expand description
Global argument of a kernel.
Fields
id: IdThe kernel id.
visibility: VisibilityWhether the global argument can only be accessed for reading, or if it can also be accessed for write.
ty: TypeThe type of the argument.
size: Option<usize>The size of the argument.
has_extended_meta: boolWhether the argument has metadata.