pub enum ProfileLevel {
Basic,
Medium,
Full,
ExecutionOnly,
}Expand description
Control the amount of info being display when profiling.
Variants
Basic
Provide only the summary information about kernels being run.
Medium
Provide the summary information about kernels being run with their trace.
Full
Provide more information about kernels being run.
ExecutionOnly
Only the execution are logged.