Module drop_queue

Module drop_queue 

Export utilities to keep track of CPU buffers when performing async data copies.

Structs

FlushingPolicy
Defines the thresholds that determine when a [PendingDropQueue] should be flushed.
PendingDropQueue
Defers the drop of CPU-side Bytes allocations until the device has finished reading them.

Traits

Fence
A synchronization primitive that blocks until the device has finished processing all commands submitted before the fence was created.