pub trait Fence {
// Required method
fn sync(self);
}Expand description
A synchronization primitive that blocks until the device has finished processing all commands submitted before the fence was created.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".