MemoryHandle

Trait MemoryHandle 

pub trait MemoryHandle<Binding>: Clone + Debug {
    // Required methods
    fn can_mut(&self) -> bool;
    fn binding(self) -> Binding;
}
The managed tensor buffer handle that points to some memory segment. It should not contain actual data.

Required Methods

fn can_mut(&self) -> bool

Checks if the underlying memory can be safely mutated.

fn binding(self) -> Binding

Get the binding associated to the current handle.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors