pub struct CubeDim(pub Dim3);Expand description
The number of units across all 3 axis totalling to the number of working units in a cube.
Tuple Fields
0: Dim3Implementations
Sourceimpl CubeDim
impl CubeDim
Sourcepub fn new<R: Runtime>(client: &ComputeClient<R>, working_units: usize) -> Self
pub fn new<R: Runtime>(client: &ComputeClient<R>, working_units: usize) -> Self
Creates a new CubeDim based on the maximum number of tasks that can be parellalized by units, in other words,
by the maximum number of working units.
Notes
For complex problems, you probably want to have your own logic function to create the
CubeDim, but for simpler problems such as elemwise-operation, this is a great default.
Sourcepub const fn new_single() -> Self
pub const fn new_single() -> Self
Create a new cube dim with x = y = z = 1.
Sourcepub const fn new_2d(x: u32, y: u32) -> Self
pub const fn new_2d(x: u32, y: u32) -> Self
Create a new cube dim with the given x and y, and z = 1.
Sourcepub const fn new_3d(x: u32, y: u32, z: u32) -> Self
pub const fn new_3d(x: u32, y: u32, z: u32) -> Self
Create a new cube dim with the given x, y and z. This is equivalent to the new function.
Sourcepub const fn can_contain(&self, other: CubeDim) -> bool
pub const fn can_contain(&self, other: CubeDim) -> bool
Whether this CubeDim can fully contain other