Handle

Struct Handle 

pub struct Handle {
    pub memory: SliceHandle,
    pub offset_start: Option<u64>,
    pub offset_end: Option<u64>,
    pub stream: StreamId,
    pub cursor: u64,
    /* private fields */
}
Server handle containing the memory handle.

Fields

memory: SliceHandle

Memory handle.

offset_start: Option<u64>

Memory offset in bytes.

offset_end: Option<u64>

Memory offset in bytes.

stream: StreamId

The stream where the data was created.

cursor: u64

The stream position when the tensor became available.

Implementations

Source

impl Handle

pub fn new( memory: SliceHandle, offset_start: Option<u64>, offset_end: Option<u64>, stream: StreamId, cursor: u64, size: u64, ) -> Self

Constructs a new Handle.

Source

impl Handle

pub fn offset_start(self, offset: u64) -> Self

Add to the current offset in bytes.

pub fn offset_end(self, offset: u64) -> Self

Add to the current offset in bytes.

pub fn size(&self) -> u64

Get the size of the handle, in bytes, accounting for offsets

Source

impl Handle

pub fn can_mut(&self) -> bool

If the tensor handle can be reused inplace.

Source

impl Handle

pub fn binding(self) -> Binding

Convert the handle into a binding.

pub fn copy_descriptor<'a>( &'a self, shape: &'a [usize], strides: &'a [usize], elem_size: usize, ) -> CopyDescriptor<'a>

Convert the handle into a binding with shape and stride metadata.