pub struct MetadataBindingInfo {
pub data: Vec<u64>,
pub dynamic_metadata_offset: usize,
}Expand description
Binding of a set of scalars of the same type to execute a kernel.
The ComputeServer is responsible to convert those info into actual [Binding] when launching
kernels.
Fields
data: Vec<u64>Scalar and metadata values
dynamic_metadata_offset: usizeStart of the dynamically sized portion of the metadata, relative to the entire info buffer
Implementations