Module storage

Module storage 

Compute Storage contract.

Structs

ManagedResource
Access to the underlying resource.
StorageHandle
Contains the storage id of a resource and the way it is used.
StorageId
Storage ID.
StorageUtilization
Defines if data uses a full memory chunk or a slice of it.

Traits

ComputeStorage
Storage types are responsible for allocating and deallocating memory.