pub struct ManagedResource<Resource: Send> { /* private fields */ }Expand description
Access to the underlying resource.
Implementations
Sourceimpl<Resource: Send> ManagedResource<Resource>
impl<Resource: Send> ManagedResource<Resource>
Sourcepub fn new(binding: ManagedMemoryBinding, resource: Resource) -> Self
pub fn new(binding: ManagedMemoryBinding, resource: Resource) -> Self
Constructs a new ManagedResource.
Sourceimpl<Resource: Send> ManagedResource<Resource>
impl<Resource: Send> ManagedResource<Resource>
Sourcepub fn resource(&self) -> &Resource
pub fn resource(&self) -> &Resource
access the underlying resource.
Note
The resource might be bigger than the part required. (e.g. a big buffer where the handle only refers to a slice of it). Only the part required by the handle is guaranteed to remain, other parts of this resource will be re-used.