GcTask

Struct GcTask 

pub struct GcTask<B: EventStreamBackend> { /* private fields */ }
A task to be enqueue on the gc stream that will be clearned after an event is reached.

Implementations

Source

impl<B: EventStreamBackend> GcTask<B>

pub fn new<T: Send + 'static>(to_drop: T, event: B::Event) -> Self

Creates a new task that will be clearned when the event is reached.