pub struct MultiStream<B: EventStreamBackend> {
pub logger: Arc<ServerLogger>,
/* private fields */
}Expand description
Manages multiple streams with synchronization logic based on shared bindings.
This struct handles the creation and alignment of streams to ensure proper synchronization when bindings (e.g., buffers) are shared across different streams.
Fields
logger: Arc<ServerLogger>The logger used by the server.
Implementations
Sourceimpl<B: EventStreamBackend> MultiStream<B>
impl<B: EventStreamBackend> MultiStream<B>
Sourcepub fn backend_mut(&mut self) -> &mut B
pub fn backend_mut(&mut self) -> &mut B
Mutable access to the stream-creation backend, e.g. to change the configuration new streams are created with. Already-created streams are unaffected.
Sourcepub fn new(logger: Arc<ServerLogger>, backend: B, max_streams: u8) -> Self
pub fn new(logger: Arc<ServerLogger>, backend: B, max_streams: u8) -> Self
Creates an empty multi-stream.
Sourcepub fn stream_ids(&self) -> impl Iterator<Item = StreamId> + '_
pub fn stream_ids(&self) -> impl Iterator<Item = StreamId> + '_
Synthetic StreamIds, one per initialized stream (see StreamPool::stream_ids).
Sourcepub fn resolve<'a>(
&mut self,
stream_id: StreamId,
handles: impl Iterator<Item = &'a BufferBinding>,
enforce_healthy: bool,
) -> Result<ResolvedStreams<'_, B>, ServerError>
pub fn resolve<'a>( &mut self, stream_id: StreamId, handles: impl Iterator<Item = &'a BufferBinding>, enforce_healthy: bool, ) -> Result<ResolvedStreams<'_, B>, ServerError>
Resolves and returns a mutable reference to the stream for the given ID, performing any necessary alignment based on the provided bindings.
This method ensures that the stream is synchronized with any shared bindings from other streams before returning the stream reference.