ResolvedStreams

Struct ResolvedStreams 

pub struct ResolvedStreams<'a, B: EventStreamBackend> {
    pub cursor: u64,
    pub current: StreamId,
    /* private fields */
}
Streams that are synchronized correctly after a MultiStream::resolve is called.

Fields

cursor: u64

The cursor on the current stream.

This cursor should be use for new allocations happening on the current stream.

current: StreamId

The current stream where new tasks can be sent safely.

Implementations

Source

impl<'a, B: EventStreamBackend> ResolvedStreams<'a, B>

pub fn get(&mut self, stream_id: &StreamId) -> &mut B::Stream

Get the stream associated to the given stream_id.

pub fn current(&mut self) -> &mut B::Stream

Get the stream associated to the current stream_id.

pub fn gc(&mut self, gc: GcTask<B>)

Enqueue a task to be cleaned.