AutotuneBound

Struct AutotuneBound 

pub struct AutotuneBound {
    pub resource: ResourceBound,
    pub threshold: f32,
}
A bound for autotuning a throughput kernel: a ResourceBound plus the threshold over which the kernel is considered accurate.

Fields

resource: ResourceBound

How much work, against what peak throughput.

threshold: f32

The threshold for this bound, over which the kernel will be considered accurate.