pub trait AutotuneOutput: Send + 'static { }Expand description
The trait to be implemented by an autotune output.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait AutotuneOutput: Send + 'static { }The trait to be implemented by an autotune output.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".