BoundsGenerator

Trait BoundsGenerator 

pub trait BoundsGenerator<K, I: TuneInputs>:
    Send
    + Sync
    + 'static {
    // Required method
    fn generate<'a>(&self, key: &K, inputs: &I::At<'a>) -> Bounds;
}
Produces a set of AutotuneBounds for a given key and reference inputs.

Required Methods

fn generate<'a>(&self, key: &K, inputs: &I::At<'a>) -> Bounds

Generate a set of bounds for a given key and reference inputs.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<K, Func, A> BoundsGenerator<K, A> for Func
where A: Clone + Send + Sync + 'static, K: 'static, Func: Send + Sync + 'static + Fn(&K, &A) -> Bounds,

Fn(&K, &A) -> Bounds acts as a BoundsGenerator when A is an owned type. For multi-input kernels, A is a tuple that the closure destructures internally.