Crate cubecl_runtime

Crate cubecl_runtime 

CubeCL runtime crate that helps creating high performance async runtimes.

Modules

allocator
Allocators moddule.
benchmark
Module for benchmark timings
client
Compute client module.
compiler
Compiler trait and related types
config
CubeCL config module.
id
Various identifier types used in CubeCL.
kernel
Kernel related traits.
logging
Logging utilities to be used by a compute server.
memory_management
Memory management module.
metadata_cache
Cache of per-launch kernel metadata info buffers. Cache of per-launch metadata info buffers (kernel shapes, strides and scalars) keyed by the exact info bytes they were built from (see [InfoCacheKey]).
runtime
Runtime trait and related types
server
Compute server module.
storage
Compute Storage module.
stream
Stream related utilities.
throughput
Throughput related utilities.
timestamp_profiler
Simple system profiling using timestamps.
tma
TMA-related runtime types
tune
Autotune module
validation
Validation utils for shared properties

Macros

local_tuner
Create a local tuner with the provided name.
storage_id_type
Create a new storage ID type.