pub struct ProfileDuration { /* private fields */ }Expand description
Result from profiling between two measurements. This can either be a duration or a future that resolves to a duration.
Implementations
Sourceimpl ProfileDuration
impl ProfileDuration
Sourcepub fn timing_method(&self) -> TimingMethod
pub fn timing_method(&self) -> TimingMethod
The method used to measure the execution time.
Sourcepub fn new(
future: Pin<Box<dyn Future<Output = ProfileTicks> + Send>>,
method: TimingMethod,
) -> ProfileDuration
pub fn new( future: Pin<Box<dyn Future<Output = ProfileTicks> + Send>>, method: TimingMethod, ) -> ProfileDuration
Create a new ProfileDuration from a future that resolves to a duration.
Sourcepub fn new_system_time(start: Instant, end: Instant) -> ProfileDuration
pub fn new_system_time(start: Instant, end: Instant) -> ProfileDuration
Create a new ProfileDuration straight from a duration.
Sourcepub fn new_device_time(
future: impl Future<Output = ProfileTicks> + Send + 'static,
) -> ProfileDuration
pub fn new_device_time( future: impl Future<Output = ProfileTicks> + Send + 'static, ) -> ProfileDuration
Create a new ProfileDuration from a future that resolves to a duration.
Sourcepub fn into_future(self) -> Pin<Box<dyn Future<Output = ProfileTicks> + Send>>
pub fn into_future(self) -> Pin<Box<dyn Future<Output = ProfileTicks> + Send>>
Retrieve the future that resolves the profile.
Sourcepub async fn resolve(self) -> ProfileTicks
pub async fn resolve(self) -> ProfileTicks
Resolve the actual duration of the profile, possibly by waiting for the future to complete.