pub enum BoundsCheckMode {
Enforce,
Validate,
Auto,
}Expand description
Bounds checks options.
Variants
Enforce
Always enforce bounds checks on every kernel launch.
Validate
Always enforce bounds checks on every kernel launch, and validate unchecked kernels for OOB.
Auto
Enforce bounds checking on standard launches, but skip checks on explicitly unchecked launches for better performance.