pub struct Logger {
pub config: Arc<CubeClRuntimeConfig>,
/* private fields */
}Expand description
Central logging utility for CubeCL, managing multiple log outputs.
Fields
config: Arc<CubeClRuntimeConfig>Global configuration for logging settings.
Implementations
Sourceimpl Logger
impl Logger
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new Logger instance based on the global configuration.
Note that creating a logger is quite expensive.
Sourcepub fn log_streaming<S: Display>(&mut self, msg: &S)
pub fn log_streaming<S: Display>(&mut self, msg: &S)
Logs a message for streaming, directing it to all configured streaming loggers.
Sourcepub fn log_memory<S: Display>(&mut self, msg: &S)
pub fn log_memory<S: Display>(&mut self, msg: &S)
Logs a message for memory, directing it to all configured memory loggers.
Sourcepub fn log_compilation<S: Display>(&mut self, msg: &S)
pub fn log_compilation<S: Display>(&mut self, msg: &S)
Logs a message for compilation, directing it to all configured compilation loggers.
Sourcepub fn log_profiling<S: Display>(&mut self, msg: &S)
pub fn log_profiling<S: Display>(&mut self, msg: &S)
Logs a message for profiling, directing it to all configured profiling loggers.
Sourcepub fn log_autotune<S: Display>(&mut self, msg: &S)
pub fn log_autotune<S: Display>(&mut self, msg: &S)
Logs a message for autotuning, directing it to all configured autotuning loggers.
Sourcepub fn log_level_streaming(&self) -> StreamingLogLevel
pub fn log_level_streaming(&self) -> StreamingLogLevel
Returns the current streaming log level from the global configuration.
Sourcepub fn log_level_autotune(&self) -> AutotuneLogLevel
pub fn log_level_autotune(&self) -> AutotuneLogLevel
Returns the current autotune log level from the global configuration.
Sourcepub fn log_level_compilation(&self) -> CompilationLogLevel
pub fn log_level_compilation(&self) -> CompilationLogLevel
Returns the current compilation log level from the global configuration.
Sourcepub fn log_level_profiling(&self) -> ProfilingLogLevel
pub fn log_level_profiling(&self) -> ProfilingLogLevel
Returns the current profiling log level from the global configuration.