pub trait Fence { // Required method fn sync(self); }
A synchronization primitive that blocks until the device has finished processing all commands submitted before the fence was created.
Block the current thread until the signals this fence.