Module server

Module server 

Compute server module.

Structs

Binding
A binding represents a Handle that is bound to managed memory.
CopyDescriptor
A binding with shape and stride info for non-contiguous reading
CubeDim
The number of units across all 3 axis totalling to the number of working units in a cube.
Handle
Server handle containing the memory handle.
KernelArguments
Arguments to execute a kernel.
MemoryLayout
An allocation with associated strides. Strides depend on tensor layout.
MemoryLayoutDescriptor
Descriptor for a new tensor allocation
MetadataBindingInfo
Binding of a set of scalars of the same type to execute a kernel.
ProfilingToken
Profiling identification so that the server can support recursive and overlapping profilings.
Reason
A reason for an error.
ServerUtilities
Contains many different types that are useful for server implementations and compute clients.
StreamErrorMode
How errors are handled in a stream when executing a task.
TensorMapBinding
A tensor map used with TMA ops
TensorMapMeta
TensorMap metadata for the opaque proxy used in TMA copies

Enums

CubeCount
Specifieds the number of cubes to be dispatched for a kernel.
CubeCountSelection
Defines how to select cube count based on the number of cubes required.
ExecutionMode
The kind of execution to be performed.
IoError
Error returned from create/read/write functions. Due to async execution not all errors are able to be caught, so some IO errors will still panic.
LaunchError
Kernel Launch Errors.
MemoryLayoutStrategy
Type of allocation, either contiguous or optimized (row-aligned when possible)
ProfileError
An error during profiling.
ReduceOperation
Different reduce operations.
ResourceLimitError
Resource limit errors.
ServerError
Error that can happen asynchronously while executing registered kernels.

Traits

ComputeServer
The compute server is responsible for handling resources and computations over resources.
MemoryLayoutPolicy
Defines how the memory layout is determined.
ServerCommunication
Defines functions for optimized data transfer between servers, supporting custom communication mechanisms such as peer-to-peer communication or specialized implementations.