pub enum CubeCount {
Static(u32, u32, u32),
Dynamic(Binding),
}Expand description
Specifieds the number of cubes to be dispatched for a kernel.
This translates to eg. a grid for CUDA, or to num_workgroups for wgsl.
Variants
Static(u32, u32, u32)
Dispatch a known count of x, y, z cubes.
Dynamic(Binding)
Dispatch an amount based on the values in this buffer. The buffer should contain a u32 array [x, y, z].
Implementations
Sourceimpl CubeCount
impl CubeCount
Sourcepub fn new_single() -> Self
pub fn new_single() -> Self
Create a new static cube count with the given x = y = z = 1.
Sourcepub fn new_2d(x: u32, y: u32) -> Self
pub fn new_2d(x: u32, y: u32) -> Self
Create a new static cube count with the given x and y, and z = 1.