CubeCountSelection

Enum CubeCountSelection 

pub enum CubeCountSelection {
    Exact(CubeCount),
    Approx(CubeCount, u32),
}
Defines how to select cube count based on the number of cubes required.

Variants



Exact(CubeCount)

If the number of cubes is the same as required.



Approx(CubeCount, u32)

If the number of cubes isn’t the same as required.

This can happen based on the hardware limit, requiring the kernel to perform OOB checks.

Implementations

Source

impl CubeCountSelection

pub fn new<R: Runtime>(client: &ComputeClient<R>, num_cubes: u32) -> Self

Creates a CubeCount while respecting the hardware limits.

pub fn has_idle(&self) -> bool

If some cubes will be idle.

pub fn cube_count(self) -> CubeCount

Converts into CubeCount.