pub enum CubeCountSelection {
Exact(CubeCount),
Approx(CubeCount, u32),
}Expand description
Defines how to select cube count based on the number of cubes required.
Variants
Exact(CubeCount)
If the number of cubes is the same as required.
Approx(CubeCount, u32)
If the number of cubes isn’t the same as required.
This can happen based on the hardware limit, requiring the kernel to perform OOB checks.
Implementations