pub struct BufferBinding {
pub memory: ManagedMemoryBinding,
pub offset_start: Option<u64>,
pub offset_end: Option<u64>,
pub stream: StreamId,
pub size: u64,
}Expand description
A buffer binding represents a Handle that is bound to managed memory.
The memory used is known by the compute server.
A buffer binding is only valid after being initlized with [super::ComputeServer::initialize_bindings]
Notes
A buffer binding is detached from a Handle, meaning that is won’t affect Handle::can_mut.
Fields
memory: ManagedMemoryBindingThe id of the handle the binding is bound to.
offset_start: Option<u64>Memory offset in bytes.
offset_end: Option<u64>Memory offset in bytes.
stream: StreamIdThe stream where the data was created.
size: u64Length of the underlying buffer ignoring offsets
Implementations
Sourceimpl BufferBinding
impl BufferBinding