Compute Storage contract.
Structs
- Managed
Resource - Access to the underlying resource.
- Storage
Handle - Contains the storage id of a resource and the way it is used.
- Storage
Id - Storage ID.
- Storage
Utilization - Defines if data uses a full memory chunk or a slice of it.
Traits
- Compute
Storage - Storage types are responsible for allocating and deallocating memory.