pub struct StorageHandle {
pub id: StorageId,
pub utilization: StorageUtilization,
}Expand description
Contains the storage id of a resource and the way it is used.
Fields
id: StorageIdStorage id.
utilization: StorageUtilizationHow the storage is used.
Implementations
Sourceimpl StorageHandle
impl StorageHandle
Sourcepub fn new(id: StorageId, utilization: StorageUtilization) -> Self
pub fn new(id: StorageId, utilization: StorageUtilization) -> Self
Constructs a new StorageHandle.
Sourceimpl StorageHandle
impl StorageHandle
Sourcepub fn offset_start(&self, offset_bytes: u64) -> Self
pub fn offset_start(&self, offset_bytes: u64) -> Self
Increase the current offset with the given value in bytes.
Sourcepub fn offset_end(&self, offset_bytes: u64) -> Self
pub fn offset_end(&self, offset_bytes: u64) -> Self
Reduce the size of the memory handle..