pub struct ResolvedStreams<'a, B: EventStreamBackend> {
pub cursor: u64,
pub current: StreamId,
/* private fields */
}Expand description
Streams that are synchronized correctly after a MultiStream::resolve is called.
Fields
cursor: u64The cursor on the current stream.
This cursor should be use for new allocations happening on the current stream.
current: StreamIdThe current stream where new tasks can be sent safely.
Implementations
Sourceimpl<'a, B: EventStreamBackend> ResolvedStreams<'a, B>
impl<'a, B: EventStreamBackend> ResolvedStreams<'a, B>