Throughput related utilities.
Structs
- Cmma
Dims - The M, N, and K dimensions of a matrix multiplication.
- Compute
Cmma Config - Configuration for a matrix multiplication (CMMA) operation.
- Kernel
Config - Configuration and payload for a benchmarkable compute kernel.
- Throughput
Benchmarker - A marker for measuring throughput of compute kernels.
- Throughput
Cache - Caches the
ThroughputValuefor a givenThroughputKey. - Throughput
Key - Represents a key/configuration used to identify the throughput of a computation.
- Throughput
Value - Represents the throughput of a computation, including the number of operations and the duration.
Enums
- Throughput
Mode - Represents the mode of a throughput computation.
Functions
- compute_
throughput_ key - Constructs a compute
ThroughputKeybased on CMMA tile availability and types. - select_
cmma_ tile - Resolves the largest supported CMMA or MMA tile size
(m, n, k).
Type Aliases
- Accumulator
Type - The element type of the accumulator.