ThroughputBenchmarker

Struct ThroughputBenchmarker 

pub struct ThroughputBenchmarker { /* private fields */ }
A marker for measuring throughput of compute kernels.

Implementations

Source

impl ThroughputBenchmarker

pub fn new(cache: Arc<Mutex<ThroughputCache>>) -> Self

Creates a new ThroughputBenchmarker with the given cache.

pub fn measure( &mut self, key: ThroughputKey, kernel_config: KernelConfig, ) -> ThroughputValue

Measure the maximum compute throughput of the given kernel. Warms up the kernel until it plateaus, then measures the throughput over multiple iterations taking the minimum time per iteration (peak attained).