pub fn tune_benchmark<'a, R: Runtime, F: TuneInputs, Out: AutotuneOutput>(
operation: &TuneFn<F, Out>,
inputs: <F as TuneInputs>::At<'a>,
client: ComputeClient<R>,
) -> Result<Vec<ProfileDuration>, AutotuneError>Expand description
Benchmark how long this operation takes for a number of samples.
Returns at least one duration, otherwise an error is returned.