pub struct AutotuneBound {
pub throughput: f64,
pub threshold: f32,
pub ops_count: usize,
}Expand description
A bound for autotuning a throughput kernel, specifying the key, threshold, and number of operations.
Fields
throughput: f64Peak throughput of the reference kernel, in ops (or bytes) per second.
threshold: f32The threshold for this bound, over which the kernel will be considered accurate.
ops_count: usizeThe number of operations the kernel will run.