AutotuneBound

Struct AutotuneBound 

pub struct AutotuneBound {
    pub throughput: f64,
    pub threshold: f32,
    pub ops_count: usize,
}
A bound for autotuning a throughput kernel, specifying the key, threshold, and number of operations.

Fields

throughput: f64

Peak throughput of the reference kernel, in ops (or bytes) per second.

threshold: f32

The threshold for this bound, over which the kernel will be considered accurate.

ops_count: usize

The number of operations the kernel will run.