LocalTuner

Struct LocalTuner 

pub struct LocalTuner<AK: AutotuneKey, ID> { /* private fields */ }
A local tuner allows to create a tuner for a specific key that can be different from the server key.

Implementations

Source

impl<AK, ID> LocalTuner<AK, ID>
where AK: AutotuneKey + 'static, ID: Hash + PartialEq + Eq + Clone + Display,

pub const fn new(name: &'static str) -> Self

Create a new local tuner.

pub fn init<I, Out, F>(&self, init_set: F) -> Arc<TunableSet<AK, I, Out>>
where F: Fn() -> TunableSet<AK, I, Out> + 'static + Send + Sync, I: TuneInputs, Out: AutotuneOutput,

Get or initialize the TunableSet for this tuner.

Returns a cached Arc<TunableSet> keyed by the TypeId of init_set. The initializer runs at most once per process.

pub fn clear(&self)

Clear the autotune state.

pub fn execute<'a, R: Runtime, I: TuneInputs, Out>( &self, id: &ID, client: &ComputeClient<R>, operations: Arc<TunableSet<AK, I, Out>>, inputs: <I as TuneInputs>::At<'a>, ) -> Out
where <I as TuneInputs>::At<'a>: Clone + Send, Out: AutotuneOutput,

Execute the fastest operation in a TunableSet, triggering a tuning pass on the first call for a given key.