pub struct LocalTuner<AK: AutotuneKey, ID> { /* private fields */ }Expand description
A local tuner allows to create a tuner for a specific key that can be different from the server key.
Implementations
Sourceimpl<AK, ID> LocalTuner<AK, ID>
impl<AK, ID> LocalTuner<AK, ID>
Sourcepub fn init<I, Out, F>(&self, init_set: F) -> Arc<TunableSet<AK, I, Out>> ⓘwhere
F: Fn() -> TunableSet<AK, I, Out> + 'static + Send + Sync,
I: TuneInputs,
Out: AutotuneOutput,
pub fn init<I, Out, F>(&self, init_set: F) -> Arc<TunableSet<AK, I, Out>> ⓘwhere
F: Fn() -> TunableSet<AK, I, Out> + 'static + Send + Sync,
I: TuneInputs,
Out: AutotuneOutput,
Get or initialize the TunableSet for this tuner.
Returns a cached Arc<TunableSet> keyed by the TypeId of init_set. The
initializer runs at most once per process.
Sourcepub fn execute<'a, R: Runtime, I: TuneInputs, Out>(
&self,
id: &ID,
client: &ComputeClient<R>,
operations: Arc<TunableSet<AK, I, Out>>,
inputs: <I as TuneInputs>::At<'a>,
) -> Out
pub fn execute<'a, R: Runtime, I: TuneInputs, Out>( &self, id: &ID, client: &ComputeClient<R>, operations: Arc<TunableSet<AK, I, Out>>, inputs: <I as TuneInputs>::At<'a>, ) -> Out
Execute the fastest operation in a TunableSet, triggering a tuning pass on
the first call for a given key.